@@ -3,6 +3,8 @@ package Games::NES::Emulator::APU;
 use strict;
 use warnings;
 
+use base qw( Class::Accessor::Fast );
+
 =head1 NAME
 
 Games::NES::Emulator::APU - NES Audio Processing Unit
@@ -13,6 +15,13 @@ Games::NES::Emulator::APU - NES Audio Processing Unit
 
 =head1 METHODS
 
+=head2 init( )
+
+=cut
+
+sub init {
+}
+
 =head1 AUTHOR
 
 Brian Cassidy E<lt>bricas@cpan.orgE<gt>
